import { AggregateRoot, AggregateID } from '@mobicoop/ddd-library';
import { v4 } from 'uuid';
import { CreateMatchProps, MatchProps } from './match.types';

export class MatchEntity extends AggregateRoot<MatchProps> {
  protected readonly _id: AggregateID;

  static create = (create: CreateMatchProps): MatchEntity => {
    const id = v4();
    const props: MatchProps = {
      ...create,
      distanceDetour: create.distance - create.initialDistance,
      durationDetour: create.duration - create.initialDuration,
      distanceDetourPercentage: parseFloat(
        ((100 * create.distance) / create.initialDistance - 100).toFixed(2),
      ),
      durationDetourPercentage: parseFloat(
        ((100 * create.duration) / create.initialDuration - 100).toFixed(2),
      ),
    };
    return new MatchEntity({ id, props });
  };

  validate(): void {
    // entity business rules validation to protect it's invariant before saving entity to a database
  }
}
